/****************************************************************************
*
*	Example Code for MNM1221
*
*	Copyright (c) 2006-2023 Panasonic Industry Co., Ltd.
*
*----------------------------------------------------------------------------
*
*	File Name:		mnm1221_s.h
*	Description:	Header file to access MNM1221 as SLAVE mode
*   Notes:
*	- This code is just for reference, so that Panasonic does NOT assume 
*	  responsibility or liability for actual use based upon this code.
*	- This file is NOT for warranty of correct behavior, 
*	  and might include bugs, so that you have to be careful.
*	- It is assumed that TAB of your PC is set to 4space width.
*
*----------------------------------------------------------------------------
*	Revision:	Date(y/m/d):	Author:			Comments:
*	0.1			2006/02/02		Y. Fujisaki		Initial release
*	0.2			2023/03/31		Y. Fujisaki		Added the registers for MDIO
*
*****************************************************************************/


/*** IMPORTANT!!! ***/
/* You must modify the following definition according to your system. */
/*--------------------------------------------------------------------------*/
/* Definition depend on your system											*/
/*--------------------------------------------------------------------------*/
/* Located Address of MNM1221 */
#define	ADDR_MNM1221		0x08000000		/* unit: byte address */

/* Data Bus Width to access to MNM1221 */
#define SLAVE_16BIT_ACCESS
/* If NOT 16bits BUT 8bits, change this definition to comments or delete it. */
/*--------------------------------------------------------------------------*/


/*--------------------------------------------------------------------------*/
/* Definition of address value (unit: byte address) 						*/
/*--------------------------------------------------------------------------*/

/*--- for memory access ----------------------------------------------------*/
#define	ADDR_TX_MEM_BGN		(ADDR_MNM1221 + 0x0000)
#define	ADDR_RX_MEM_BGN		(ADDR_MNM1221 + 0x0200)

/*--- for SLAVE control ----------------------------------------------------*/
#define	ADDR_S_RESET		(ADDR_MNM1221 + 0x0500)
#define	ADDR_S_MACID		(ADDR_MNM1221 + 0x0504)
#define	ADDR_S_BLK_N		(ADDR_MNM1221 + 0x0508)
#define	ADDR_S_TIMEOUT		(ADDR_MNM1221 + 0x050C)
#define	ADDR_S_INIT_DONE	(ADDR_MNM1221 + 0x0510)
#define	ADDR_S_INTRX_MSK	(ADDR_MNM1221 + 0x0514)
#define	ADDR_S_SYNC_DELAY	(ADDR_MNM1221 + 0x0518)
#define	ADDR_S_SYNC_MSK		(ADDR_MNM1221 + 0x051C)

#define	ADDR_S_TXMEM_SW		(ADDR_MNM1221 + 0x0530)
#define	ADDR_S_RXMEM_HOLD	(ADDR_MNM1221 + 0x0534)

#define	ADDR_S_MDIO_WDAT	(ADDR_MNM1221 + 0x0520)
#define	ADDR_S_MDIO_ADDR	(ADDR_MNM1221 + 0x0524)
#define	ADDR_S_MDIO_WR		(ADDR_MNM1221 + 0x0528)
#define	ADDR_S_MDIO_RD		(ADDR_MNM1221 + 0x052C)

/*--- for SLAVE status -----------------------------------------------------*/
#define	ADDR_S_STATE		(ADDR_MNM1221 + 0x0544)
#define	ADDR_S_OVER_N		(ADDR_MNM1221 + 0x0548)
#define	ADDR_S_ERR_FLAGS	(ADDR_MNM1221 + 0x054C)
#define	ADDR_S_DCRC_ERR_L	(ADDR_MNM1221 + 0x0550)
#define	ADDR_S_DCRC_ERR_H	(ADDR_MNM1221 + 0x0554)

#define	ADDR_S_NODE_ORDER	(ADDR_MNM1221 + 0x0558)
#define	ADDR_S_BLK_ORDER	(ADDR_MNM1221 + 0x055C)
#define	ADDR_S_NODE_SUM		(ADDR_MNM1221 + 0x0560)
#define	ADDR_S_BLK_SUM		(ADDR_MNM1221 + 0x0564)

#define	ADDR_S_MDIO_RDAT	(ADDR_MNM1221 + 0x056C)
/*--------------------------------------------------------------------------*/


#ifdef SLAVE_16BIT_ACCESS
/*--------------------------------------------------------------------------*/
/* Register definition for SLAVE 16bit-bus access 							*/
/*--------------------------------------------------------------------------*/
/*--- pointer for memory block copy ----------------------------------------*/
#define	P_MNM1221_TX_MEM_BGN	((volatile unsigned short *)ADDR_TX_MEM_BGN)
#define	P_MNM1221_RX_MEM_BGN	((volatile unsigned short *)ADDR_RX_MEM_BGN)

/*--- for memory access ----------------------------------------------------*/
#define	MNM1221_TX_MEM_BGN		(*P_MNM1221_TX_MEM_BGN)
#define	MNM1221_RX_MEM_BGN		(*P_MNM1221_RX_MEM_BGN)

/*--- for control ----------------------------------------------------------*/
#define	MNM1221_S_RESET			(*((volatile unsigned short *)ADDR_S_RESET))
#define	MNM1221_S_MACID			(*((volatile unsigned short *)ADDR_S_MACID))
#define	MNM1221_S_BLK_N			(*((volatile unsigned short *)ADDR_S_BLK_N))
#define	MNM1221_S_TIMEOUT		(*((volatile unsigned short *)ADDR_S_TIMEOUT))
#define	MNM1221_S_INIT_DONE		(*((volatile unsigned short *)ADDR_S_INIT_DONE))
#define	MNM1221_S_INTRX_MSK		(*((volatile unsigned short *)ADDR_S_INTRX_MSK))
#define	MNM1221_S_SYNC_DELAY	(*((volatile unsigned short *)ADDR_S_SYNC_DELAY))
#define	MNM1221_S_SYNC_MSK		(*((volatile unsigned short *)ADDR_S_SYNC_MSK))

#define	MNM1221_S_TXMEM_SW		(*((volatile unsigned short *)ADDR_S_TXMEM_SW))
#define	MNM1221_S_RXMEM_HOLD	(*((volatile unsigned short *)ADDR_S_RXMEM_HOLD))

#define	MNM1221_S_MDIO_WDAT		(*((volatile unsigned short *)ADDR_S_MDIO_WDAT))
#define	MNM1221_S_MDIO_ADDR		(*((volatile unsigned short *)ADDR_S_MDIO_ADDR))
#define	MNM1221_S_MDIO_WR		(*((volatile unsigned short *)ADDR_S_MDIO_WR))
#define	MNM1221_S_MDIO_RD		(*((volatile unsigned short *)ADDR_S_MDIO_RD))

/*--- for status -----------------------------------------------------------*/
#define	MNM1221_S_STATE			(*((volatile unsigned short *)ADDR_S_STATE))
#define	MNM1221_S_OVER_N		(*((volatile unsigned short *)ADDR_S_OVER_N))
#define	MNM1221_S_ERR_FLAGS		(*((volatile unsigned short *)ADDR_S_ERR_FLAGS))
#define	MNM1221_S_DCRC_ERR_L	(*((volatile unsigned short *)ADDR_S_DCRC_ERR_L))
#define	MNM1221_S_DCRC_ERR_H	(*((volatile unsigned short *)ADDR_S_DCRC_ERR_H))

#define	MNM1221_S_NODE_ORDER	(*((volatile unsigned short *)ADDR_S_NODE_ORDER))
#define	MNM1221_S_BLK_ORDER		(*((volatile unsigned short *)ADDR_S_BLK_ORDER))
#define	MNM1221_S_NODE_SUM		(*((volatile unsigned short *)ADDR_S_NODE_SUM))
#define	MNM1221_S_BLK_SUM		(*((volatile unsigned short *)ADDR_S_BLK_SUM))

#define	MNM1221_S_MDIO_RDAT		(*((volatile unsigned short *)ADDR_S_MDIO_RDAT))
/*--------------------------------------------------------------------------*/

#else
/*--------------------------------------------------------------------------*/
/* Register definition for SLAVE 8bit-bus access 							*/
/*--------------------------------------------------------------------------*/
/*--- pointer for memory block copy ----------------------------------------*/
#define	P_MNM1221_TX_MEM_BGN	((volatile unsigned char *)ADDR_TX_MEM_BGN)
#define	P_MNM1221_RX_MEM_BGN	((volatile unsigned char *)ADDR_RX_MEM_BGN)

/*--- for memory access ----------------------------------------------------*/
#define	MNM1221_TX_MEM_BGN		(*P_MNM1221_TX_MEM_BGN)
#define	MNM1221_RX_MEM_BGN		(*P_MNM1221_RX_MEM_BGN)

/*--- for control ----------------------------------------------------------*/
#define	MNM1221_S_RESET			(*((volatile unsigned char *)ADDR_S_RESET))
#define	MNM1221_S_MACID			(*((volatile unsigned char *)ADDR_S_MACID))
#define	MNM1221_S_BLK_N			(*((volatile unsigned char *)ADDR_S_BLK_N))
#define	MNM1221_S_TIMEOUT		(*((volatile unsigned char *)ADDR_S_TIMEOUT))
#define	MNM1221_S_INIT_DONE		(*((volatile unsigned char *)ADDR_S_INIT_DONE))
#define	MNM1221_S_INTRX_MSK		(*((volatile unsigned char *)ADDR_S_INTRX_MSK))
#define	MNM1221_S_SYNC_DELAY	(*((volatile unsigned char *)ADDR_S_SYNC_DELAY))
#define	MNM1221_S_SYNC_MSK		(*((volatile unsigned char *)ADDR_S_SYNC_MSK))

#define	MNM1221_S_TXMEM_SW		(*((volatile unsigned char *)ADDR_S_TXMEM_SW))
#define	MNM1221_S_RXMEM_HOLD	(*((volatile unsigned char *)ADDR_S_RXMEM_HOLD))

#define	MNM1221_S_MDIO_WDATL	(*((volatile unsigned char *)ADDR_S_MDIO_WDAT))
#define	MNM1221_S_MDIO_WDATH	(*((volatile unsigned char *)(ADDR_S_MDIO_WDAT + 1)))
#define	MNM1221_S_MDIO_ADDRL	(*((volatile unsigned char *)ADDR_S_MDIO_ADDR))
#define	MNM1221_S_MDIO_ADDRH	(*((volatile unsigned char *)(ADDR_S_MDIO_ADDR + 1)))
#define	MNM1221_S_MDIO_WR		(*((volatile unsigned char *)ADDR_S_MDIO_WR))
#define	MNM1221_S_MDIO_RD		(*((volatile unsigned char *)ADDR_S_MDIO_RD))

/*--- for status -----------------------------------------------------------*/
#define	MNM1221_S_STATE_L		(*((volatile unsigned char *)ADDR_S_STATE))
#define	MNM1221_S_STATE_H		(*((volatile unsigned char *)(ADDR_S_STATE + 1)))
#define	MNM1221_S_OVER_N		(*((volatile unsigned char *)ADDR_S_OVER_N))
#define	MNM1221_S_ERR_FLAGSL	(*((volatile unsigned char *)ADDR_S_ERR_FLAGS))
#define	MNM1221_S_ERR_FLAGSH	(*((volatile unsigned char *)(ADDR_S_ERR_FLAGS + 1)))
#define	MNM1221_S_DCRC_ERRLL	(*((volatile unsigned char *)ADDR_S_DCRC_ERR_L))
#define	MNM1221_S_DCRC_ERRLH	(*((volatile unsigned char *)(ADDR_S_DCRC_ERR_L + 1)))
#define	MNM1221_S_DCRC_ERRHL	(*((volatile unsigned char *)ADDR_S_DCRC_ERR_H))
#define	MNM1221_S_DCRC_ERRHH	(*((volatile unsigned char *)(ADDR_S_DCRC_ERR_H + 1)))

#define	MNM1221_S_NODE_ORDER	(*((volatile unsigned char *)ADDR_S_NODE_ORDER))
#define	MNM1221_S_BLK_ORDER		(*((volatile unsigned char *)ADDR_S_BLK_ORDER))
#define	MNM1221_S_NODE_SUM		(*((volatile unsigned char *)ADDR_S_NODE_SUM))
#define	MNM1221_S_BLK_SUM		(*((volatile unsigned char *)ADDR_S_BLK_SUM))

#define	MNM1221_S_MDIO_RDATL	(*((volatile unsigned char *)ADDR_S_MDIO_RDAT))
#define	MNM1221_S_MDIO_RDATH	(*((volatile unsigned char *)(ADDR_S_MDIO_RDAT + 1)))
/*--------------------------------------------------------------------------*/

#endif


/*--------------------------------------------------------------------------*/
/* General definition														*/
/*--------------------------------------------------------------------------*/
#define MAX_N_SLAVE_NODE		32		/* maximum number of slave nodes */
#define	BYTE_SIZE_OF_BLOCK		16		/* size of memory block per 1node  */
#define	WORD_SIZE_OF_BLOCK		(BYTE_SIZE_OF_BLOCK / 2)
#define	DWORD_SIZE_OF_BLOCK		(BYTE_SIZE_OF_BLOCK / 4)

#ifdef SLAVE_16BIT_ACCESS
	#define	SIZE_OF_BLOCK		WORD_SIZE_OF_BLOCK		/* 16bits */
#else
	#define	SIZE_OF_BLOCK		BYTE_SIZE_OF_BLOCK		/* 8bits */
#endif

/*--------------------------------------------------------------------------*/

/***************************************************** End of mnm1221_s.h ***/

